<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/ui_mainwindow.h" line="569"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="46"/>
        <location filename="../src/ui_mainwindow.h" line="571"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="49"/>
        <location filename="../src/ui_mainwindow.h" line="573"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <location filename="../src/ui_mainwindow.h" line="575"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="87"/>
        <location filename="../src/ui_mainwindow.h" line="578"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="90"/>
        <location filename="../src/ui_mainwindow.h" line="580"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="96"/>
        <location filename="../src/ui_mainwindow.h" line="582"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="112"/>
        <location filename="../src/ui_mainwindow.h" line="584"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="169"/>
        <location filename="../src/ui_mainwindow.h" line="586"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="194"/>
        <location filename="../src/ui_mainwindow.h" line="591"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="197"/>
        <location filename="../src/ui_mainwindow.h" line="593"/>
        <source>About...</source>
        <translation>À propos&#xa0;…</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="203"/>
        <location filename="../src/ui_mainwindow.h" line="595"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="597"/>
        <source>View Log</source>
        <translation>Afficher le journal</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="253"/>
        <location filename="../src/mainwindow.cpp" line="583"/>
        <location filename="../src/mainwindow.cpp" line="606"/>
        <location filename="../src/ui_mainwindow.h" line="598"/>
        <source>Select ISO</source>
        <translation>Choisir une image ISO</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="263"/>
        <location filename="../src/ui_mainwindow.h" line="599"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du périphérique USB cible&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="273"/>
        <location filename="../src/ui_mainwindow.h" line="600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du fichier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="289"/>
        <location filename="../src/ui_mainwindow.h" line="601"/>
        <source>Advanced Options</source>
        <translation>Options avancées</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="307"/>
        <location filename="../src/ui_mainwindow.h" line="602"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Créer le système de fichiers ext4 même s’il en existe déjà un</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="314"/>
        <location filename="../src/ui_mainwindow.h" line="603"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Conserver le répertoire boot originel lors de la mise à jour du live-usb</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="321"/>
        <location filename="../src/ui_mainwindow.h" line="605"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Utiliser le partitionnement gpt à la place de msdos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <location filename="../src/ui_mainwindow.h" line="607"/>
        <source>GPT partitioning</source>
        <translation>Partitionnement GPT</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="331"/>
        <location filename="../src/ui_mainwindow.h" line="608"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Mettre à jour (met uniquement à jour un live-usb existant)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="338"/>
        <location filename="../src/ui_mainwindow.h" line="610"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne pas remplacer les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="341"/>
        <location filename="../src/ui_mainwindow.h" line="612"/>
        <source>Keep syslinux files</source>
        <translation>Conserver les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="348"/>
        <location filename="../src/ui_mainwindow.h" line="613"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorer les vérifications USB/Démontable</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="355"/>
        <location filename="../src/ui_mainwindow.h" line="614"/>
        <source>Temporarily disable automounting</source>
        <translation>Désactiver temporairement le montage automatique</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="365"/>
        <location filename="../src/ui_mainwindow.h" line="618"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Activer le marqueur pmbr_boot sur le disque (ne démarre pas via UEFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="372"/>
        <location filename="../src/ui_mainwindow.h" line="619"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>N’utilisez pas fuseiso pour monter des images iso</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="398"/>
        <location filename="../src/ui_mainwindow.h" line="620"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Taille de la partition ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <location filename="../src/ui_mainwindow.h" line="621"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosité (du moins au plus):</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/ui_mainwindow.h" line="623"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="506"/>
        <location filename="../src/ui_mainwindow.h" line="628"/>
        <source>Data partition format type</source>
        <translation>Type de format de la partition de données</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="460"/>
        <location filename="../src/ui_mainwindow.h" line="622"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="470"/>
        <location filename="../src/ui_mainwindow.h" line="624"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="475"/>
        <location filename="../src/ui_mainwindow.h" line="625"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="499"/>
        <location filename="../src/ui_mainwindow.h" line="627"/>
        <source>Make separate data partition (percent)</source>
        <translation>Créer une partition de données séparée (pourcent) </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="516"/>
        <location filename="../src/ui_mainwindow.h" line="629"/>
        <source>Refresh drive list</source>
        <translation>Rafraîchir la liste des lecteurs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="529"/>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <location filename="../src/ui_mainwindow.h" line="630"/>
        <source>Show advanced options</source>
        <translation>Afficher les options avancées</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="548"/>
        <location filename="../src/ui_mainwindow.h" line="631"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="632"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Mode complet - Li&amp;veUSB accessible en écriture</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="573"/>
        <location filename="../src/ui_mainwindow.h" line="634"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Lecture seule, incompatible avec la persistance</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="576"/>
        <location filename="../src/ui_mainwindow.h" line="636"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>&amp;Mode image - LiveUSB (dd) en lecture seule</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="589"/>
        <location filename="../src/ui_mainwindow.h" line="637"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pour une distribution autre qu’antiX ou MX, utilisez le mode image (dd).</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="637"/>
        <location filename="../src/ui_mainwindow.h" line="638"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="675"/>
        <location filename="../src/ui_mainwindow.h" line="639"/>
        <source>Percent of USB-device to use:</source>
        <translation>Pourcentage du périphérique USB à utiliser:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="682"/>
        <location filename="../src/ui_mainwindow.h" line="640"/>
        <source>Label ext partition:</source>
        <translation>Étiquette de la partition:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="730"/>
        <location filename="../src/ui_mainwindow.h" line="642"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne pas lancer de commande affectant le périphérique usb</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="733"/>
        <location filename="../src/ui_mainwindow.h" line="644"/>
        <source>Dry run (no change to system)</source>
        <translation>Test (aucune modification du système)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="740"/>
        <location filename="../src/ui_mainwindow.h" line="646"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Cloner à partir d’un usb-live monté ou d’un fichier iso.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="743"/>
        <location filename="../src/ui_mainwindow.h" line="648"/>
        <source>Clone a mounted live system</source>
        <translation>Cloner un système live monté</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="750"/>
        <location filename="../src/ui_mainwindow.h" line="650"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Organise le démarrage depuis une partition chiffrée. Exigera une phrase de passe au premier démarrage.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="753"/>
        <location filename="../src/ui_mainwindow.h" line="652"/>
        <source>Encrypt</source>
        <translation>Chiffrer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="760"/>
        <location filename="../src/ui_mainwindow.h" line="653"/>
        <source>Clone running live system</source>
        <translation>Cloner un système live en fonctionnement</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <location filename="../src/mainwindow.cpp" line="705"/>
        <source>Failure</source>
        <translation>Échec</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>La source et la destination sont sur le même périphérique, veuillez recommencer la sélection.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="750"/>
        <source>Source Error</source>
        <translation>Erreur source</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="751"/>
        <source>Could not find the source linuxfs file.</source>
        <translation>Impossible de trouver le fichier source linuxfs.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="772"/>
        <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
        <translation>Avertissement: Le périphérique cible (%1) est plus petit que la source (%2). Les données risquent de ne pas tenir. Voulez-vous continuer?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Size Warning</source>
        <translation>Avertissement: Taille insuffisante</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="783"/>
        <source>The target device %1 is larger than %2 GB.

This may indicate you have selected the wrong device.
Are you sure you want to proceed?</source>
        <translation>Le périphérique cible %1 est plus grand que %2 Go.

Cela peut indiquer que vous avez sélectionné le mauvais périphérique.
Êtes-vous sûr•e de vouloir continuer?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="790"/>
        <source>Large Target Device Warning</source>
        <translation>Avertissement: Le périphérique cible est de trop grande taille</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation>Écriture de %1 à l’aide de la commande «&#xa0;dd&#xa0;» sur /dev/%2.

Veuillez patienter jusqu’à la fin de la procédure.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <source>MX Live Usb Maker</source>
        <translation>MX Live USB Création - MX Live USB Maker</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>LiveUSB creation successful!</source>
        <translation>Création du Live USB accomplie!</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Erreurs rencontrées pendant le processus de création du Live USB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Please select a USB device to write to</source>
        <translation>Veuillez choisir le périphérique USB sur lequel écrire</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ces actions supprimeront toutes les données sur 

</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="468"/>
        <source>Do you wish to continue?</source>
        <translation>Souhaitez-vous continuer?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="500"/>
        <source>About %1</source>
        <translation>À propos %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="501"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="503"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programme de création d’un live-usb à partir d’un fichier ISO, d’un autre live-usb, d’un live-cd/dvd ou d’un système live en fonctionnement.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="506"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="507"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="522"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Choisir le fichier ISO qui sera gravé sur le périphérique USB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="523"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>Fichiers ISO (*.iso);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Select Source Directory</source>
        <translation>Choix du répertoire source</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <source>Could not find linuxfs file</source>
        <translation>Impossible de trouver le fichier linuxfs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <source>Hide advanced options</source>
        <translation>Cacher les options avancées</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <location filename="../src/mainwindow.cpp" line="596"/>
        <source>Select Source</source>
        <translation>Choisir la source</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="582"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Select ISO file</source>
        <translation>Choisir le fichier ISO</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="598"/>
        <source>clone</source>
        <translation>clone</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Could not find a log file at: </source>
        <translation>Impossible de trouver un fichier journal dans: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="74"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <location filename="../src/about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programme de création d’un live-usb à partir d’un fichier ISO, d’un autre live-usb, d’un live-cd/dvd ou d’un système live en fonctionnement.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>filename</source>
        <translation>nom de fichier</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Name of .iso file to open</source>
        <translation>Nom du fichier .iso à ouvrir</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <source>[filename]</source>
        <translation>[nom de fichier]</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <location filename="../src/main.cpp" line="102"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur•rice normal•e pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>You must run this program as root.</source>
        <translation>Vous devez exécuter cette application en tant que root.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>version:</source>
        <translation>version:</translation>
    </message>
</context>
</TS>
